function Pulse = RectPulse( fsT )
% RectPulse - rectangular pulse
%
% Generate a rectangular pulse spanning one symbol period with fsT samples
% per symbol period. The amplitude of the pulse is normalized so that the
% pulse has energy T.
%
%          p(t) = 1 for 0 <= t < T
% 
% Inputs:
%   fsT - number of samples 
%
% Example:
%   Pulse = RectPulse( fsT )

Pulse(1:fsT) = 1;
